==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/FinancialLegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { FinancialLegendDescription } from "./FinancialLegendDescription";
/**
 * @hidden
 */
var FinancialLegendDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialLegendDescriptionMetadata, _super);
    function FinancialLegendDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialLegendDescriptionMetadata.b = function (a) {
        if (FinancialLegendDescriptionMetadata.a == null) {
            FinancialLegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialLegendDescriptionMetadata.c(FinancialLegendDescriptionMetadata.a);
        }
        if (a.k(FinancialLegendDescriptionMetadata.a)) {
            return;
        }
        a.ab(FinancialLegendDescriptionMetadata.a);
    };
    FinancialLegendDescriptionMetadata.c = function (a) {
        LegendBaseDescriptionMetadata.c(a);
    };
    FinancialLegendDescriptionMetadata.d = function (a) {
        FinancialLegendDescriptionMetadata.b(a);
        a.ad("FinancialLegend", function () { return new FinancialLegendDescription(); });
        a.ac("FinancialLegend", FinancialLegendDescriptionMetadata.a);
    };
    FinancialLegendDescriptionMetadata.$t = markType(FinancialLegendDescriptionMetadata, 'FinancialLegendDescriptionMetadata');
    FinancialLegendDescriptionMetadata.a = null;
    return FinancialLegendDescriptionMetadata;
}(Base));
export { FinancialLegendDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/FinancialLegendDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LegendBaseDescriptionMetadata } from "./LegendBaseDescriptionMetadata";
import { FinancialLegendDescription } from "./FinancialLegendDescription";
/**
 * @hidden
 */
var FinancialLegendDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialLegendDescriptionMetadata, _super);
    function FinancialLegendDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialLegendDescriptionMetadata.b = function (a) {
        if (FinancialLegendDescriptionMetadata.a == null) {
            FinancialLegendDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialLegendDescriptionMetadata.c(FinancialLegendDescriptionMetadata.a);
        }
        if (a.k(FinancialLegendDescriptionMetadata.a)) {
            return;
        }
        a.ac(FinancialLegendDescriptionMetadata.a);
    };
    FinancialLegendDescriptionMetadata.c = function (a) {
        LegendBaseDescriptionMetadata.c(a);
    };
    FinancialLegendDescriptionMetadata.d = function (a) {
        FinancialLegendDescriptionMetadata.b(a);
        a.ae("FinancialLegend", function () { return new FinancialLegendDescription(); });
        a.ad("FinancialLegend", FinancialLegendDescriptionMetadata.a);
    };
    FinancialLegendDescriptionMetadata.$t = markType(FinancialLegendDescriptionMetadata, 'FinancialLegendDescriptionMetadata');
    FinancialLegendDescriptionMetadata.a = null;
    return FinancialLegendDescriptionMetadata;
}(Base));
export { FinancialLegendDescriptionMetadata };
